@@ -5,9 +5,9 @@ import copy
 import subprocess
 import time
 import glob
-from scripting import import_ng0
-from scripting import get_kidney_params
-from scripting import get_mono_params
+from .scripting import import_ng0
+from .scripting import get_kidney_params
+from .scripting import get_mono_params
 from joblib import Parallel,delayed 
 import multiprocessing as mp
 
